@@ -1,4 +1,6 @@
 import pytest
+
+from lambda_packer.config import Config
 from lambda_packer.template_utils import (
     generate_lambda_handler,
     generate_package_config,
@@ -18,10 +20,14 @@ def test_generate_lambda_handler():
 
 def test_generate_package_config():
     lambda_name = "test_lambda"
-    expected_output = """lambdas:
+    expected_output = f"""lambdas:
   test_lambda:
     type:
     - zip
+    file_name: lambda
+    function_name: lambda_handler
+    runtime: '{Config.default_python_runtime}'
+    platforms: {Config.default_platforms}
     layers:
       - common
 """
